@@ -8,7 +8,7 @@
  * \wd \taz \greg \mysid
  * \date 1996-2001
  *
- * $Id: db.c,v 1.2 2003/08/17 16:13:35 Mysid Exp $
+ * $Id: db.c,v 1.3 2004/02/12 04:46:26 Mysid Exp $
  */
 
 /*
@@ -998,7 +998,8 @@ void readMemoData(void)
 
 			/* Memo expiration code */
 
-			if ((time(NULL) - newmemo->sent) >= NICKDROPTIME) {
+			if ((time(NULL) - newmemo->sent) >= NICKDROPTIME
+			     && !(newmemo->flags & MEMO_SAVE)) {
 				FREE(newmemo);
 				continue;
 			}
